@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
+    Copyright (C) 1996-2007 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -256,7 +256,7 @@ for ( ; ; )
     }
    }
   modfood = atoi(key);
-  strncpy(buff,key,128);
+  strncpy(buff,key,60);
   token = strtok(buff, ", ");
   token = strtok(NULL,", ");
   if (strcmp(key,"") == 0 || modfood == 0) break;
@@ -455,12 +455,14 @@ for ( ; ; )
  if (nutnum == ALA ) food_work.nutrient[F18D3] = tempfloat;
  if (nutnum == EPA ) food_work.nutrient[F20D5] = tempfloat;
  if (nutnum == DHA ) food_work.nutrient[F22D6] = tempfloat;
+ if (nutnum == ENERC_KCAL ) food_work.nutrient[ENERC_KJ] = tempfloat * 4.1835;
  if (nutnum == TOCPHA) food_work.nutrient[VITE] = tempfloat * 3/2;
  if (nutnum == F18D2 ) food_work.nutrient[LA] = tempfloat;
  if (nutnum == F20D4 ) food_work.nutrient[AA] = tempfloat;
  if (nutnum == F18D3 ) food_work.nutrient[ALA] = tempfloat;
  if (nutnum == F20D5 ) food_work.nutrient[EPA] = tempfloat;
  if (nutnum == F22D6 ) food_work.nutrient[DHA] = tempfloat;
+ if (nutnum == ENERC_KJ ) food_work.nutrient[ENERC_KCAL] = tempfloat / 4.1835;
  }
 }
 
