@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
+    Copyright (C) 1996-2007 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ char nutdir1[]=".nutdb";
 char nutdir1[]=NUTDIR ;
 #endif
 
-char USDAjoined1[] = "sr18.nut";
+char USDAjoined1[] = "sr19.nut";
 char globalFOOD1[] = "FOOD_DES.txt";
 char globalNUT1[] = "NUT_DATA.txt";
 char globalWEIGHT1[] = "WEIGHT.txt";
@@ -124,6 +124,10 @@ while (fgets(buffer,800,fp) != NULL)
  while (*bufptr != '^') bufptr++;
  *bufptr = '\0' ; bufptr++;
  new_food->ndb_no = atoi(fieldptr);
+ fieldptr = bufptr;
+ while (*bufptr != '^') bufptr++;
+ *bufptr = '\0' ; bufptr++;
+ new_food->fdgrp = atoi(fieldptr);
  fieldptr = new_food->name;
  while (*bufptr != '^')
   {
@@ -202,6 +206,7 @@ while (fgets(buffer,400,fp) != NULL)
    abort();
    }
   new_food->ndb_no = ndbno;
+  if (ndbno >= 99000) new_food->fdgrp = 0;
   for (count = 0; count < NUTRIENT_COUNT; count++) new_food->nutrient[count] = NoData;
   if (ndbno >= options.next_recipe) options.next_recipe = ndbno + 1;
   food_ptr = new_food;
@@ -871,11 +876,11 @@ strcpy(subuser,sub);
  mkdir (nutdir, 0700 );
  sprintf(nutdirsubuser,"%s/%s","NUTDB",subuser);
  mkdir (nutdirsubuser, 0700 );
- sprintf(USDAjoined,"%s/%s","NUTSR18",USDAjoined1);
- sprintf(globalFOOD,"%s/%s","NUTSR18",globalFOOD1);
- sprintf(globalNUT,"%s/%s","NUTSR18",globalNUT1);
- sprintf(globalWEIGHT,"%s/%s","NUTSR18",globalWEIGHT1);
- sprintf(weightlib,"%s/%s","NUTSR18",weightlib1);
+ sprintf(USDAjoined,"%s/%s","NUTSR19",USDAjoined1);
+ sprintf(globalFOOD,"%s/%s","NUTSR19",globalFOOD1);
+ sprintf(globalNUT,"%s/%s","NUTSR19",globalNUT1);
+ sprintf(globalWEIGHT,"%s/%s","NUTSR19",globalWEIGHT1);
+ sprintf(weightlib,"%s/%s","NUTSR19",weightlib1);
  sprintf(localFOOD,"%s/%s/%s","NUTDB",subuser,localFOOD1);
  sprintf(localNUT,"%s/%s/%s","NUTDB",subuser,localNUT1);
  sprintf(localWEIGHT,"%s/%s/%s","NUTDB",subuser,localWEIGHT1);
